@@ -8,26 +8,54 @@ from pathlib import Path
 from googleapiclient.discovery import build
 from google.oauth2 import service_account
 
+import pygsheets
+
 
 class Connection:
+    """
+    Establishes authentication for google API products
+
+    Needs the client_secret.json from the Google Developer Console
+    
+    Class will create a folder in the CWD (if it doesn't exist)
+    Authenticate via oAuth2.0
+    Return a resource object to be used in the other wrapper classes
+
+    Current methods for authenication
+    .gsc()
+    .ga()
+    .cal()
+    .sheets()
+    .gbq() * requires a separate service account authentication file * 
+    .gmail()
+    """
     def __init__(self, file_path="client_secret.json"):
         self.file_path = file_path
         self.dir_check()
 
     def dir_check(self):
-        if Path("./credentials/").is_dir():
-            pass
-        else:
+        # if there isn't a crednetials folder, create one
+        if not Path("./credentials/").is_dir():
             Path("./credentials/").mkdir()
 
-    def authenticate(self, scope, token_name):
-        """Initializes the analyticsreporting service object.
+    def authenticate(self, scope, token_name,http_return=True):
+        """
+        Authenticates Google Product using oauth2
+        Saves the credentials in the ./credentials folder
+        Returns the authroized resource object
 
-        Returns:
-          analytics an authorized analyticsreporting service object.
+        Params:
+        scope: list of strings (urls from google)
+            to find list of all scopes
+                https://developers.google.com/identity/protocols/oauth2/scopes
+
+        token_name: string: what we will name our crednetials.dat file
+
+        Method is based on Google Analytics Authentication found here:
+        https://developers.google.com/analytics/devguides/
+            reporting/core/v4/quickstart/installed-py#3_setup_the_sample
         """
         # Parse command-line arguments.
-        # DO I Need this?
         parser = argparse.ArgumentParser(
             formatter_class=argparse.RawDescriptionHelpFormatter,
             parents=[tools.argparser],
@@ -48,11 +76,14 @@ class Connection:
         # credentials will get written back to a file.
         storage = file.Storage(f"./credentials/{token_name}.dat")
         credentials = storage.get()
+
         if credentials is None or credentials.invalid:
             credentials = tools.run_flow(flow, storage, flags)
-        http = credentials.authorize(http=httplib2.Http())
+        
+        if http_return:
+            return credentials.authorize(http=httplib2.Http())
 
-        return http
+        return credentials
 
     def gsc(self):
         scope_list = ["https://www.googleapis.com/auth/webmasters.readonly"]
@@ -70,6 +101,9 @@ class Connection:
         scope_list = ["https://www.googleapis.com/auth/calendar"]
         return build("calendar", "v3", http=self.authenticate(scope_list, "calendar"))
 
+    def pygsheets(self):
+        return pygsheets.authorize(local=True,credentials_directory='./credentials/')
+
     def sheets(self):
         scope_list = [
             "https://www.googleapis.com/auth/drive",
